.. _iupac_code:

The IUPAC code
==============

The International Union of Pure and Applied Chemistry (IUPAC_) defined
the standard code for representing protein or DNA sequences.

Nucleic IUPAC Code
------------------

======== =================================
**Code**     **Nucleotide**
======== =================================
   A       Adenine
   C       Cytosine
   G       Guanine
   T       Thymine
   U       Uracil
   R       Purine (A or G)
   Y       Pyrimidine (C, T, or U)
   M       C or A
   K       T, U, or G
   W       T, U, or A
   S       C or G
   B       C, T, U, or G (not A)
   D       A, T, U, or G (not C)
   H       A, T, U, or C (not G)
   V       A, C, or G (not T, not U)
   N       Any base (A, C, G, T, or U)
======== =================================



.. _IUPAC: http://www.iupac.org/
